@@ -12,7 +12,7 @@ use Search::Tools::UTF8;
 use Search::Tools::XML;
 use Search::Tools::RegEx;
 
-our $VERSION = '0.37';
+our $VERSION = '0.38';
 
 my $XML = Search::Tools::XML->new();
 my $C2E = $XML->char2ent_map;
@@ -142,11 +142,12 @@ sub _extract_terms {
     my $default_field = $self->default_field;
 
     if ( length($default_field) && $Search::QueryParser::VERSION le 0.93 ) {
-        carp "upgrade Search::QueryParser to 0.94 or later to use default_field.";
+        carp
+            "upgrade Search::QueryParser to 0.94 or later to use default_field.";
     }
 
     my $esc_wildcard = quotemeta($wildcard);
-    my $word_re      = qr/([$wordchar]+($esc_wildcard)?)/;
+    my $word_re      = qr/(($esc_wildcard)?[$wordchar]+($esc_wildcard)?)/;
 
     # backcompat allows for query to be array ref.
     # this called only from S::T::Keywords
